@@ -1,4 +1,4 @@
-__all__ = ['FileOperationsBase', 'QueryExecutorBase']
+__all__ = ['FileOperationsBase', 'QueryExecutorBase', 'NotebookExecutorBase']
 
 from .fileops import *
 from .query_executor import *
