@@ -1325,8 +1325,14 @@ def test_loading(params):
     nextstep = False
     try:
         modname = params['modname']
-        cmd = """import {}""".format(modname)
-        exec(cmd)
+        pkgdir  = params['pkgdir']
+        if params.get('isfile', False):
+            file_, path_, desc_ = imp.find_module(modname, [pkgdir])
+            params['mod'] = imp.load_module(modname, file_, path_, desc_)
+        else:
+            cmd = """import {}""".format(modname)
+            exec(cmd)
+
         if modname not in sys.modules:
             print(redbg('Imported {} but cannot find in sys.modules'.format(modname)))
         else:
@@ -1581,7 +1587,7 @@ def test_conf_pipeline(conf, context):
         'enrich_data_dir': os.environ['ENRICH_DATA']
     }
 
-    usecase_root = conf.get('usecase_root', conf['customer_root'])
+    usecase_root = conf.get('usecase_root', conf.get('customer_root',"Unknown"))
     params.update({
         'usecase_root': usecase_root % params,
         # Backward compatability
@@ -1812,6 +1818,8 @@ def test_transform(pkgdir, capture=False, context=None):
 
     """
 
+    pkgdir = os.path.abspath(pkgdir)
+
     # Setup logging
     if capture:
         setup_logging()
@@ -1836,6 +1844,7 @@ def test_transform(pkgdir, capture=False, context=None):
     #   x/x/__init__.py
     #   x/src/x/__init__.py
     #
+
     modname = None
     if os.path.isfile(pkgdir):
         dirname = os.path.dirname(pkgdir)
@@ -1866,6 +1875,8 @@ def test_transform(pkgdir, capture=False, context=None):
         raise Exception("Unable to load usecase details")
 
     params = {
+        'path': pkgdir,
+        'isfile': os.path.isfile(pkgdir),
         'pkgdir': dirname,
         'modname': modname,
         'config': config,
