@@ -318,8 +318,8 @@ class MockConfig(object):
 
         if ((enrichjson is None) or
             (not os.path.exists(enrichjson))):
-            logger.error("Unable to find enrich.json")
-            return
+            logger.warning("Unable to find enrich.json")
+            return {}
 
         try:
             enrich = json.load(open(enrichjson))
