@@ -24,26 +24,28 @@ class TransformBase(object):
     """
     def __init__(self, *args, **kwargs):
         self.version = "v1.0"
+        self.name = self.display = self.__class__.__name__
         self.pipeline = None
-        self.config = kwargs.pop('config',{})
+        self.args = {}
 
-        # Call initialize
-        self.initialize()
+    def configure(self, pipeline, args):
+
+        self.pipeline = pipeline
+        self.args = args
+
+        # Override the transform name..
+        self.enable  = self.args.get('enable', True)
+        self.display = self.args.get('display', self.display)
+        self.version = self.args.get('version', self.version)
 
     def initialize(self):
         pass
 
     def process(self, state):
-        return state
+        pass
 
     def __str__(self):
-        if hasattr(self, 'shortname'):
-            name = self.shortname
-        elif hasattr(self, 'name'):
-            name = self.name
-        else:
-            name = self.__class__.__name__
-        return "{}:{}".format(name, self.version)
+        return "{}:{}".format(self.display, self.version)
 
     def get_pipeline_extra(self):
         if self.pipeline is not None:
@@ -62,7 +64,7 @@ class RedisTransformBase(TransformBase):
         super().__init__(*args, **kwargs)
 
     def initialize(self):
-        connparams = self.config.get('connection', {})
+        connparams = self.args.get('connection', {})
         self.backend = RedisBackend(config=connparams)
         self.backend.connect()
 
@@ -70,13 +72,12 @@ class RedisReadTransform(RedisTransformBase):
     """
     Read from Redis
     """
-    @property
-    def shortname(self):
-        return "RDR"
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def process(self, state):
 
-        key = self.config.get('key',None)
+        key = self.args.get('key',None)
         if key is None:
             return state
 
@@ -88,7 +89,7 @@ class RedisReadTransform(RedisTransformBase):
             logger.exception("Cant compute the key")
             return state
 
-        name = self.config.get('name', 'dbrow')
+        name = self.args.get('name', 'dbrow')
         dbrow = self.backend.get(key)
         state.put(name, dbrow)
 
@@ -98,19 +99,18 @@ class RedisWriteTransform(RedisTransformBase):
     """
     Write to Redis
     """
-    @property
-    def shortname(self):
-        return "RDW"
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def process(self, state):
 
-        key = self.config.get('key',None)
+        key = self.args.get('key',None)
         if key is None:
             return state
 
         streamrow = state.get('streamrow')
 
-        name = self.config.get('name', 'dbrow')
+        name = self.args.get('name', 'dbrow')
         dbrow = state.get(name)
 
         try:
@@ -134,13 +134,12 @@ class RedisWriteTransform(RedisTransformBase):
 ##############################################
 class MetaStartTransform(TransformBase):
 
-    @property
-    def shortname(self):
-        return "MDS"
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def process(self, state):
 
-        state = super().process(state)
+        super().process(state)
 
         streamrow = state.get('streamrow')
 
@@ -159,13 +158,12 @@ class MetaStartTransform(TransformBase):
 
 class MetaEndTransform(TransformBase):
 
-    @property
-    def shortname(self):
-        return "MDE"
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def process(self, state):
 
-        state = super().process(state)
+        super().process(state)
 
         streamrow = state.get('streamrow')
 
@@ -183,18 +181,16 @@ class MetaEndTransform(TransformBase):
 
 class LoggerTransform(TransformBase):
 
-    @property
-    def shortname(self):
-        return "LOG"
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def initialize(self):
-
-        name = self.config.get('name', 'app')
+        name = self.args.get('name', __name__)
         self.logger = logging.getLogger(name)
 
     def process(self, state):
 
-        state = super().process(state)
+        super().process(state)
 
         streamrow = state.get('streamrow')
         dbrow = state.get('dbrow',{})
@@ -202,7 +198,7 @@ class LoggerTransform(TransformBase):
         # Clean up the record before posting
         streamrow.pop('message',"")
         streamrow['_meta_'].pop('message',"")
-        extra = self.config.get('extra',{})
+        extra = self.args.get('extra',{})
         extra['data'] = {
             'streamrow': streamrow,
             'dbrow': dbrow
