@@ -13,6 +13,8 @@ import logging
 
 logger = logging.getLogger('app')
 
+from .transforms import TransformBase
+
 class State(object):
     """
     Internal state objects. Transform classes use this
@@ -29,6 +31,9 @@ class State(object):
     def get(self, name, default=None):
         return self.frames.get(name, default)
 
+    def dumps(self):
+        return str(self.frames.keys())
+
 class WorkflowBase(object):
     """
     Base class to define a workflow. This class registers new
@@ -43,14 +48,40 @@ class WorkflowBase(object):
         self.debug = kwargs.get('debug', False)
         self.transforms = []
 
-    def add(self, t):
-        if isinstance(t, list):
-            self.transforms.extend(t)
-        else:
-            self.transforms.append(t)
+    def add(self, specs, **kwargs):
 
-        for t in self.transforms:
-            t.pipeline = self
+        if not isinstance(specs, list):
+            raise Exception("Add expects a list of specifications")
+
+        globalargs = self.config.get('args', {})
+
+        for index, spec in enumerate(specs):
+
+            if issubclass(spec, TransformBase):
+                transform = spec
+                name = spec.__name__ # class
+            elif isinstance(spec, dict):
+                if 'transform' not in spec:
+                    raise Exception("Spec dictionary should include a 'transform' class")
+                transform = spec['transform']
+                name = spec.get('name', transform.name)
+            else:
+                raise Exception(f"Unexpected data type {type(spec)}")
+
+            # Instantiate the transform...
+            t = transform(**kwargs)
+
+            # Configure it with the new args...
+            args = globalargs.get(name,{})
+            args['name'] = name
+            t.configure(pipeline=self,args=args)
+
+            # Do any other initialization such as connecting to the
+            # database..
+            t.initialize()
+
+            # Add it and keep it ready for use..
+            self.transforms.append(t)
 
     def process(self, streamrow={}):
         """
@@ -63,6 +94,8 @@ class WorkflowBase(object):
 
         for t in self.transforms:
             try:
+                if not t.enable:
+                    continue
                 t.process(state)
             except:
                 logger.exception("Unable to process")
